package com.persagy.fm.depproject.model;

import com.persagy.fm.depproject.model.dto.AddDepProjectDTO;
import com.persagy.fm.depproject.model.dto.UpdateDepProjectDTO;
import org.mapstruct.Mapper;
import org.mapstruct.MappingTarget;
import org.mapstruct.NullValueCheckStrategy;
import org.mapstruct.NullValueMappingStrategy;
import org.mapstruct.factory.Mappers;

import java.util.List;

/**
 * 部门项目(DepProject) dto、vo、do转换工具类
 *
 * @author lixing
 * @version V1.0 2021-03-24 10:08:14 2021-03-24 10:08:14
 */
@Mapper(nullValueMappingStrategy = NullValueMappingStrategy.RETURN_DEFAULT,
        nullValueCheckStrategy = NullValueCheckStrategy.ALWAYS)
public interface ConvertDepProjectTool {

    ConvertDepProjectTool INSTANCE = Mappers.getMapper(ConvertDepProjectTool.class);

    /**
     * addDTO转换为do
     *
     * @param addDepProjectDTO addDTO
     * @return 要创建的do对象
     * @author lixing
     * @version V1.0 2021-03-24 10:08:14
     */
    DepProject convertAddDto2Entity(AddDepProjectDTO addDepProjectDTO);

    /**
     * updateDTO转换为实体
     *
     * @param depProject          更新前的do对象
     * @param updateDepProjectDTO updateDTO
     * @return 更新后的do对象
     * @author lixing
     * @version V1.0 2021-03-24 10:08:14
     */
    DepProject convertUpdateDto2Entity(@MappingTarget DepProject depProject, UpdateDepProjectDTO updateDepProjectDTO);

    /**
     * addDTO列表转换为do列表
     *
     * @param addDepProjectDTOList addDTO列表
     * @return do列表
     * @author lixing
     * @version V1.0 2021/3/24 10:22 上午
     */
    List<DepProject> convert2EntityList(List<AddDepProjectDTO> addDepProjectDTOList);
}

