package com.persagy.fm.person.model.dto;

import com.persagy.fm.common.constant.RegexConstants;
import com.persagy.fm.saas.project.model.dto.UpsertSaasProjectDTO;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import net.minidev.json.annotate.JsonIgnore;
import org.hibernate.validator.constraints.Length;

import javax.validation.constraints.Email;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.Pattern;
import java.util.Date;
import java.util.List;

/**
 * 创建和更新人员基类
 *
 * @author lixing
 * @version V1.0 2021/3/23 11:09 上午
 **/
@Data
@ApiModel
public class UpsertPersonDTO {
    @ApiModelProperty(value = "姓名", required = true)
    @NotEmpty(message = "姓名不能为空")
    @Length(max = 20, message = "姓名长度不能大于20")
    @Pattern(regexp = RegexConstants.ALL_REGEX, message = "姓名" + RegexConstants.ALL_REGEX_WARNING)
    private String name;

    @Pattern(regexp = RegexConstants.EN_NUM_BLANK_REGEX, message = "工号" + RegexConstants.EN_NUM_REGEX_WARNING)
    @Length(max = 50, message = "工号长度不能大于50")
    @ApiModelProperty(value = "工号")
    private String jobNumber;

    @ApiModelProperty(value = "生日")
    private Date birthday;

    @ApiModelProperty(value = "性别")
    private Integer gender;

    @ApiModelProperty(value = "员工类型", notes = "com.persagy.fm.person.constant.enums.PersonTypeEnum")
    private String personType;

    @Pattern(regexp = RegexConstants.PHONE_OR_BLANK_REGEX, message = RegexConstants.PHONE_REGEX_WARNING)
    @Length(max = 11, message = "手机号码长度不能大于11")
    @ApiModelProperty(value = "手机号码")
    private String phoneNum;

    @ApiModelProperty(value = "证件类型", notes = "com.persagy.fm.person.constant.enums.CertificateTypeEnum")
    private String certificateType;

    @Pattern(regexp = RegexConstants.ID_CARD_OR_BLANK_REGEX, message = RegexConstants.ID_CARD_REGEX_WARNING)
    @Length(max = 18, message = "证件号码长度不能大于18")
    @ApiModelProperty(value = "证件号码")
    private String idNumber;

    @Email(message = RegexConstants.EMAIL_REGEX_WARNING)
    @ApiModelProperty(value = "邮箱")
    private String mail;

    @Length(max = 50, message = "备注长度不能大于50")
    @ApiModelProperty(value = "备注")
    private String remark;

    @NotEmpty(message = "部门不能为空")
    @ApiModelProperty(value = "所属部门id", required = true)
    private List<String> depIds;

    @ApiModelProperty(value = "主岗")
    private String mainDuty;

    @ApiModelProperty(value = "副岗")
    private List<String> otherDuties;

    @ApiModelProperty(value = "直接上级")
    private String leader;

    @ApiModelProperty(value = "专业")
    private List<String> professions;

    @ApiModelProperty(value = "附加权限")
    private List<String> otherRoles;

    @Pattern(regexp = RegexConstants.EN_NUM_CHAR_REGEX, message = "账号" + RegexConstants.EN_NUM_CHAR_REGEX_WARNING)
    @Length(max = 30, message = "账号长度不能大于30")
    @ApiModelProperty(value = "账号", required = true)
    @NotEmpty(message = "账号不能为空")
    private String username;

    @ApiModelProperty("登录权限(年.月.日)")
    private Date expireDate;

    /**
     * 账号来源
     */
    @JsonIgnore
    @ApiModelProperty(hidden = true)
    private String userFrom;

    /**
     * 账号id
     */
    @JsonIgnore
    @ApiModelProperty(hidden = true)
    private String accountId;

    @ApiModelProperty(value = "项目权限")
    private List<UpsertSaasProjectDTO> projects;
}
