package com.persagy.fm.person.model.vo;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import com.persagy.fm.common.model.vo.SimpleObjVO;
import com.persagy.fm.department.model.vo.DepSimpleObjVO;
import com.persagy.fm.saas.project.model.vo.ProjectVO;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.util.Date;
import java.util.List;

import com.fasterxml.jackson.annotation.JsonInclude;
import org.assertj.core.util.Lists;

/**
 * @author lixing
 * @version V1.0 2021-03-15 17:20:33
 */
@Data
@ApiModel(value = "人员返回结果参数")
@JsonInclude(JsonInclude.Include.NON_NULL)
public class ResponsePersonItemVO {
    @ApiModelProperty("id")
    @JsonSerialize(using = ToStringSerializer.class)
    private String id;

    @ApiModelProperty("姓名")
    private String name;

    @ApiModelProperty(value = "工号")
    private String jobNumber;

    @ApiModelProperty(value = "生日")
    private Date birthday;

    @ApiModelProperty(value = "性别")
    private Integer gender;

    @ApiModelProperty(value = "员工类型id")
    @JsonIgnore
    private String personType;

    @ApiModelProperty(value = "员工类型", notes = "com.persagy.fm.person.constant.enums.PersonTypeEnum")
    private SimpleObjVO personTypeVO;

    @ApiModelProperty(value = "头像")
    private String headPortrait;

    @ApiModelProperty(value = "手机号码")
    private String phoneNum;

    @ApiModelProperty(value = "证件类型id")
    @JsonIgnore
    private String certificateType;

    @ApiModelProperty(value = "证件类型", notes = "com.persagy.fm.person.constant.enums.CertificateTypeEnum")
    private SimpleObjVO certificateTypeVO;

    @ApiModelProperty("证件号码")
    private String idNumber;

    @ApiModelProperty(value = "邮箱")
    private String mail;

    @ApiModelProperty(value = "备注")
    private String remark;

    @ApiModelProperty(value = "所属部门id")
    @JsonIgnore
    private List<Long> depIds;

    @ApiModelProperty(value = "所属部门")
    private List<DepSimpleObjVO> deps;

    @ApiModelProperty(value = "关联的项目id")
    @JsonIgnore
    private List<String> projectIds;

    @ApiModelProperty(value = "关联的项目名称")
    private List<ProjectVO> projects;

    @ApiModelProperty(value = "主岗")
    private SimpleObjVO mainDuty;

    @ApiModelProperty(value = "副岗")
    private List<SimpleObjVO> otherDuties;

    @ApiModelProperty(value = "直接上级id")
    @JsonIgnore
    private Long leader;

    @ApiModelProperty(value = "直接上级")
    private SimpleObjVO leaderVO;

    @ApiModelProperty(value = "专业id")
    @JsonIgnore
    private String profession;

    @ApiModelProperty(value = "专业")
    private List<SimpleObjVO> professions;

    @ApiModelProperty(value = "附加权限")
    private List<SimpleObjVO> otherRoles;

    @ApiModelProperty("账号")
    private String username;

    @ApiModelProperty("账号id")
    private String accountId;

    @ApiModelProperty("登录权限(年.月.日/永久)")
    private Date expireDate;

    @ApiModelProperty("账号来源")
    private String userFrom;

    @ApiModelProperty("创建时间")
    private Date creationTime;

    @ApiModelProperty("创建用户")
    private String creator;

    @ApiModelProperty("更新用户")
    private String modifier;

    @ApiModelProperty("更新时间")
    private Date modifiedTime;

    @ApiModelProperty("在职状态")
    private String hiredState;

    @ApiModelProperty("启用状态")
    private String enableState;

    public SimpleObjVO getPersonTypeVO() {
        return personTypeVO == null ? new SimpleObjVO() : personTypeVO;
    }

    public SimpleObjVO getCertificateTypeVO() {
        return certificateTypeVO == null ? new SimpleObjVO() : certificateTypeVO;
    }

    public List<DepSimpleObjVO> getDeps() {
        return deps == null ? Lists.newArrayList() : deps;
    }

    public List<ProjectVO> getProjects() {
        return projects == null ? Lists.newArrayList() : projects;
    }

    public SimpleObjVO getMainDuty() {
        return mainDuty == null ? new SimpleObjVO() : mainDuty;
    }

    public List<SimpleObjVO> getOtherDuties() {
        return otherDuties == null ? Lists.newArrayList() : otherDuties;
    }

    public SimpleObjVO getLeaderVO() {
        return leaderVO == null ? new SimpleObjVO() : leaderVO;
    }

    public List<SimpleObjVO> getProfessions() {
        return professions == null ? Lists.newArrayList() : professions;
    }

    public List<SimpleObjVO> getOtherRoles() {
        return otherRoles == null ? Lists.newArrayList() : otherRoles;
    }
}
