package com.persagy.fm.person.service.impl;

import com.persagy.fm.department.model.vo.ManagerSimpleObjVO;
import com.persagy.fm.person.model.Person;
import com.persagy.fm.person.service.IPersonQueryService;
import com.persagy.fm.translate.service.ITranslator;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.assertj.core.util.Lists;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.*;

/**
 * 人员姓名翻译器
 *
 * @author lixing
 * @version V1.0 2021/3/29 8:12 下午
 */
@Slf4j
@Service
public class PersonNameTranslator implements ITranslator {

    @Autowired
    private IPersonQueryService personQueryService;

    @Override
    public String trans(String parameter) {
        if (StringUtils.isBlank(parameter)) {
            return "";
        }
        Person person = personQueryService.queryPersonProfile(parameter);
        return person.getName();
        //        if(StringUtils.isBlank(parameter)) {
        //            return null;
        //        }
        //        String[] ids = parameter.split(",");
        //        List<Long> idList = Lists.newArrayList();
        //
        //        for (String id : ids) {
        //            idList.add(Long.valueOf(id));
        //        }
        //        List<Person> personList = personService.queryByIds(idList);
        //        return personList.stream().map(person -> {
        //            ManagerVO managerVO = new ManagerVO();
        //            managerVO.setId(person.getId());
        //            managerVO.setName(person.getName());
        //            return managerVO;
        //        }).collect(Collectors.toList());
    }

    @Override
    public Map<String, Object> transBatch(List<String> parameter) {
        if (CollectionUtils.isEmpty(parameter)) {
            return null;
        }
        Set<String> idSet = new HashSet<>();
        for (String para : parameter) {
            String[] ids = StringUtils.split(para, ",");
            idSet.addAll(Arrays.asList(ids));
        }
        List<String> idList = new ArrayList<>(idSet);
        Map<String, Object> idMap = new HashMap<>(16);
        List<Person> personList = personQueryService.queryByIds(idList);
        personList.forEach(person -> idMap.put(String.valueOf(person.getId()), person.getName()));
        Map<String, Object> resultMap = new HashMap<>(16);
        for (String para : parameter) {
            String[] ids = StringUtils.split(para, ",");
            List<ManagerSimpleObjVO> managerSimpleObjVOList = Lists.newArrayList();
            for (String id : ids) {
                ManagerSimpleObjVO managerSimpleObjVO = new ManagerSimpleObjVO();
                managerSimpleObjVO.setId(id);
                managerSimpleObjVO.setName(idMap.get(id).toString());
                managerSimpleObjVOList.add(managerSimpleObjVO);
            }
            Map<String, List<ManagerSimpleObjVO>> showNameMap = new HashMap<>(1);
            showNameMap.put("name", managerSimpleObjVOList);
            resultMap.put(para, showNameMap);
        }
        return resultMap;
    }
}
