package com.persagy.fm.profession.controller;

import com.persagy.fm.common.response.*;
import com.persagy.fm.common.utils.ResultHelper;
import com.persagy.fm.profession.model.ConvertProfessionTool;
import com.persagy.fm.profession.model.Profession;
import com.persagy.fm.profession.model.dto.AddProfessionDTO;
import com.persagy.fm.profession.model.dto.DeleteProfessionDTO;
import com.persagy.fm.profession.model.dto.UpdateProfessionDTO;
import com.persagy.fm.profession.model.vo.ResponseProfessionListItemVO;
import com.persagy.fm.profession.service.IProfessionService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;
import java.util.List;

/**
 * 专业控制层
 *
 * @author lixing
 * @version V1.0 2021-03-19 16:38:18
 */
@Api(tags = "专业")
@Validated
@RestController
@RequestMapping("professions")
public class ProfessionController {
    @Autowired
    private IProfessionService professionService;

    @ApiOperation(value = "创建专业")
    @PostMapping("/create")
    public CommonResult<FmResponseUpsertVO> createProfession(
            @Valid @RequestBody AddProfessionDTO addProfessionDTO) {
        String id = professionService.createProfession(addProfessionDTO);
        return ResultHelper.single(new FmResponseUpsertVO(id));
    }


    @ApiOperation(value = "更新专业")
    @PostMapping("/update")
    public CommonResult<FmResponseUpsertVO> updateProfession(
            @Valid @RequestBody UpdateProfessionDTO updateProfessionDTO) {
        professionService.updateProfession(updateProfessionDTO);
        return ResultHelper.single(new FmResponseUpsertVO(updateProfessionDTO.getId()));
    }


    @ApiOperation(value = "删除专业")
    @PostMapping("/delete")
    public CommonResult deleteProfession(
            @RequestBody @Valid DeleteProfessionDTO deleteProfessionDTO) {
        professionService.deleteProfession(deleteProfessionDTO.getId());
        return ResultHelper.success("删除成功");
    }


    @ApiOperation(value = "专业列表")
    @PostMapping("/query")
    public CommonResult<PageList<ResponseProfessionListItemVO>> queryProfession() {
        List<Profession> professionList = professionService.queryProfessionList();
        List<ResponseProfessionListItemVO> resultList = ConvertProfessionTool.INSTANCE.convert2List(professionList);
        return ResultHelper.multi(resultList);
    }

    @ApiOperation(value = "校验是否可删除")
    @PostMapping("/checkDeletable")
    public CommonResult checkDeletable(
            @RequestBody @Valid DeleteProfessionDTO deleteProfessionDTO) {
        professionService.checkDeletable(deleteProfessionDTO.getId());
        return ResultHelper.success();
    }

}

