package com.persagy.fm.saas.account.client;

import com.persagy.fm.common.client.FeignConfig;
import com.persagy.fm.common.response.FmResponseContent;
import com.persagy.fm.common.response.FmResponseMsg;
import com.persagy.fm.saas.account.client.fallback.SaasAccountClientFallbackFactory;
import com.persagy.fm.saas.account.model.dto.*;
import com.persagy.fm.saas.account.model.vo.SaasAccountListItemVO;
import com.persagy.fm.saas.project.constant.FeignClientNameConstants;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;

import java.util.List;

/**
 * 运维平台账号接口feign客户端
 *
 * @author lixing
 * @version V1.0 2021/3/22 2:13 下午
 **/
@FeignClient(name = FeignClientNameConstants.SAAS, fallbackFactory = SaasAccountClientFallbackFactory.class,
        configuration = FeignConfig.class)
public interface SaasAccountClient {
    /**
     * 分页查询账号列表
     *
     * @param pageQuerySaasAccountDTO 查询条件
     * @return 账号列表
     * @author lixing
     * @version V1.0 2021/3/23 11:57 上午
     */
    @PostMapping("/account/queryAccountPageList")
    FmResponseContent<List<SaasAccountListItemVO>> querySaasAccountPageList(@RequestBody PageQuerySaasAccountDTO pageQuerySaasAccountDTO);

    /**
     * 创建账号
     *
     * @param addSaasAccountDTO 创建账号入参
     * @return 账号id
     * @author lixing
     * @version V1.0 2021/3/23 11:57 上午
     */
    @PostMapping("/account/createSaasAccount")
    FmResponseContent<String> createSaasAccount(@RequestBody AddSaasAccountDTO addSaasAccountDTO);

    /**
     * 更新账号
     *
     * @param updateSaasAccountDTO 更新账号入参
     * @author lixing
     * @return FmResponseMsg
     * @version V1.0 2021/3/23 11:57 上午
     */
    @PostMapping("/account/updateSaasAccount")
    FmResponseMsg updateSaasAccount(@RequestBody UpdateSaasAccountDTO updateSaasAccountDTO);

    /**
     * 禁用账号
     *
     * @param deleteSaasAccountDTO 删除账号入参
     * @return 禁用是否成功
     * @author lixing
     * @version V1.0 2021/3/30 8:16 下午
     */
    @PostMapping("/account/deleteSaasAccount")
    FmResponseMsg disableAccount(@RequestBody DeleteSaasAccountDTO deleteSaasAccountDTO);

    /**
     * 启用账号
     *
     * @param enableSaasAccountDTO 启用账号入参
     * @return 启用是否成功
     * @author lixing
     * @version V1.0 2021/3/30 8:16 下午
     */
    @PostMapping("/account/enableSaasAccount")
    FmResponseMsg enableAccount(@RequestBody EnableSaasAccountDTO enableSaasAccountDTO);
}
