package com.persagy.fm.saas.accountrole.service;

import com.persagy.fm.common.response.FmResponseContent;
import com.persagy.fm.saas.accountrole.model.*;
import com.persagy.fm.saas.accountrole.model.dto.*;

import java.util.List;
import java.util.Map;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.persagy.fm.saas.accountrole.model.vo.AccountRoleVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

/**
 * 账号-角色关联信息(SaasAccountRole) service接口
 *
 * @author lixing
 * @version V1.0 2021-03-25 09:39:38
 */
public interface ISaasAccountRoleService {

    /**
     * 创建账号-角色关联信息
     *
     * @param addSaasAccountRoleDTO addDTO
     * @return 账号-角色关联信息主键
     * @author lixing
     * @version V1.0 2021-03-25 09:39:38
     */
    String createSaasAccountRole(AddSaasAccountRoleDTO addSaasAccountRoleDTO);

    /**
     * 删除账号-角色关联信息
     *
     * @param accountId 账号主键
     * @author lixing
     * @version V1.0 2021-03-25 09:39:38
     */
    void deleteSaasAccountRole(String accountId);

    /**
     * 查询账号-角色关联信息
     *
     * @param querySaasAccountRoleDTO queryDTO
     * @return List<SaasAccountRole>
     * @author lixing
     * @version V1.0 2021-03-25 09:39:38
     */
    List<SaasAccountRole> querySaasAccountRoleList(QuerySaasAccountRoleDTO querySaasAccountRoleDTO);

    /**
     * 查询角色关联的账号id
     *
     * @param roleIds 角色列表
     * @return 账号id列表
     * @author lixing
     * @version V1.0 2021/4/30 10:35 上午
     */
    List<String> queryAccountIdByRoleIdList(List<String> roleIds);

    /**
     * 根据账号id列表查询账号-角色关联信息
     *
     * @param accountIdList 账号id列表
     * @return List<SaasAccountRole>
     * @author lixing
     * @version V1.0 2021/4/1 9:48 上午
     */
    List<SaasAccountRole> querySaasAccountRoleListByAccountIdList(List<String> accountIdList);

    /**
     * 根据账号id列表查询账号-角色关联信息
     *
     * @param accountIdList 账号id列表
     * @return Map<String, AccountRoleVO> accountId -> AccountRoleVO
     * @author lixing
     * @version V1.0 2021/4/1 9:48 上午
     */
    Map<String, AccountRoleVO> queryAccountRoleVoMapByAccountIdList(List<String> accountIdList);

    /**
     * 重置账号与角色的关联
     *
     * @param accountId 账号id
     * @param roles 更新后的角色信息
     * @author lixing
     * @version V1.0 2021/4/8 2:55 下午
     */
    void resetSaasAccountRole(String accountId, List<AddSaasAccountRoleDTO> roles);

    /**
     * 重置账号与角色的关联
     *
     * @param accountId 账号id
     * @param accountRoleType 账号角色关联类型（主岗、副岗、附加角色）
     * @param roles 更新后的角色信息
     * @author lixing
     * @version V1.0 2021/4/8 2:55 下午
     */
    void resetSaasAccountRole(String accountId, String accountRoleType, List<AddSaasAccountRoleDTO> roles);
}
