package com.persagy.fm.saas.role.model;

import org.mapstruct.*;
import org.mapstruct.MappingTarget;
import org.mapstruct.factory.Mappers;
import com.persagy.fm.saas.role.model.vo.*;
import com.persagy.fm.saas.role.model.dto.*;

import java.util.List;

/**
 * (SaasRole) dto、vo、do转换工具类
 *
 * @author lixing
 * @version V1.0 2021-03-22 19:04:28 2021-03-22 19:04:28
 */
@Mapper(nullValueMappingStrategy = NullValueMappingStrategy.RETURN_DEFAULT,
        nullValueCheckStrategy = NullValueCheckStrategy.ALWAYS)
public interface ConvertSaasRoleTool {

    ConvertSaasRoleTool INSTANCE = Mappers.getMapper(ConvertSaasRoleTool.class);

    /**
     * do转换为ResponseItemVO
     *
     * @param saasRole do对象
     * @return ResponseItemVO
     * @author lixing
     * @version V1.0 2021-03-22 19:04:28
     */
    SaasRoleItemVO convert2ResponseItemDTO(SaasRole saasRole);

    /**
     * do转换为ResponseListItemVO
     *
     * @param saasRole do对象
     * @return ResponseListItemVO
     * @author lixing
     * @version V1.0 2021-03-22 19:04:28
     */
    @Mapping(source = "countFunction", target = "relatedFunCount")
    SaasRoleListItemVO convert2ResponseListItemDTO(SaasRole saasRole);

    /**
     * do列表转换为ResponseListItemVO列表
     *
     * @param saasRoleList do列表
     * @return ResponseListItemVO列表
     * @author lixing
     * @version V1.0 2021-03-22 19:04:28
     */
    List<SaasRoleListItemVO> convert2List(List<SaasRole> saasRoleList);

    /**
     * addDTO转换为do
     *
     * @param addSaasRoleDTO addDTO
     * @return 要创建的do对象
     * @author lixing
     * @version V1.0 2021-03-22 19:04:28
     */
    SaasRole convertAddDto2Entity(AddSaasRoleDTO addSaasRoleDTO);

    /**
     * updateDTO转换为实体
     *
     * @param saasRole          更新前的do对象
     * @param updateSaasRoleDTO updateDTO
     * @return 更新后的do对象
     * @author lixing
     * @version V1.0 2021-03-22 19:04:28
     */
    SaasRole convertUpdateDto2Entity(@MappingTarget SaasRole saasRole, UpdateSaasRoleDTO updateSaasRoleDTO);
}

