package com.persagy.fm.workresume.service;

import com.persagy.fm.workresume.model.WorkResume;
import com.persagy.fm.workresume.model.dto.AddWorkResumeDTO;
import com.persagy.fm.workresume.model.dto.PageQueryWorkResumeDTO;
import com.persagy.fm.workresume.model.dto.QueryWorkResumeDTO;
import com.persagy.fm.workresume.model.dto.UpdateWorkResumeDTO;

import java.util.List;

import com.baomidou.mybatisplus.core.metadata.IPage;

/**
 * 工作信息(WorkResume) service接口
 *
 * @author lixing
 * @version V1.0 2021-03-15 17:20:06
 */
public interface IWorkResumeService {

    /**
     * 创建工作信息
     *
     * @param addWorkResumeDTO addDTO
     * @return 工作信息主键
     * @author lixing
     * @version V1.0 2021-03-15 17:20:06
     */
    String createWorkResume(AddWorkResumeDTO addWorkResumeDTO);

    /**
     * 工作信息详情
     *
     * @param id 主键
     * @return 工作信息do对象
     * @author lixing
     * @version V1.0 2021-03-15 17:20:06
     */
    WorkResume queryWorkResumeDetail(String id);

    /**
     * 更新工作信息
     *
     * @param updateWorkResumeDTO updateDTO
     * @author lixing
     * @version V1.0 2021-03-15 17:20:06
     */
    void updateWorkResume(UpdateWorkResumeDTO updateWorkResumeDTO);

    /**
     * 删除工作信息
     *
     * @param id 主键
     * @author lixing
     * @version V1.0 2021-03-15 17:20:06
     */
    void deleteWorkResume(String id);

    /**
     * 查询工作信息
     *
     * @param queryWorkResumeDTO queryDTO
     * @return List<WorkResume>
     * @author lixing
     * @version V1.0 2021-03-15 17:20:06
     */
    List<WorkResume> queryWorkResumeList(QueryWorkResumeDTO queryWorkResumeDTO);

    /**
     * 查询一组人员的工作信息
     *
     * @param personIdList 一组人员id
     * @return List<WorkResume>
     * @author lixing
     * @version V1.0 2021-03-15 17:20:06
     */
    List<WorkResume> queryWorkResumeListByPersonIdList(List<String> personIdList);

    /**
     * 批量更新工作信息
     *
     * @param workResumes 工作信息列表
     * @author lixing
     * @version V1.0 2021/3/30 8:26 下午
     */
    void batchUpdateWorkResume(List<WorkResume> workResumes);

    /**
     * 更新人员的工作信息在职状态
     *
     * @param personId 人员id 不可为空
     * @param workResumeHiredState 工作信息在职状态
     * @author lixing
     * @version V1.0 2021/3/31 5:32 下午
     */
    void changeWorkResumeHiredStateByPersonId(String personId, String workResumeHiredState);

    /**
     * 更新人员的工作信息启用状态
     *
     * @param personId 人员id 不可为空
     * @param workResumeEnableState 工作信息启用状态
     * @author lixing
     * @version V1.0 2021/3/31 5:32 下午
     */
    void changeWorkResumeEnableStateByPersonId(String personId, String workResumeEnableState);

    /**
     * 获取部门的负责人
     *
     * @param depId 部门id
     * @return 部门的负责人id列表
     * @author lixing
     * @version V1.0 2021/4/2 6:01 下午
     */
    List<String> queryDepManagers(String depId);

    /**
     * 更新人员的工作信息
     *
     * @param personId 人员id
     * @param addedDepIds 添加的部门
     * @param deletedDepIds 删除的部门
     * @author lixing
     * @version V1.0 2021/4/6 11:21 上午
     */
    void updatePersonWorkResume(String personId, List<String> addedDepIds, List<String> deletedDepIds);
}
