package com.persagy.fm.scheduling.utils;

import com.google.common.collect.Lists;
import lombok.Getter;
import lombok.RequiredArgsConstructor;

import java.util.List;
import java.util.Objects;
import java.util.function.Function;
import java.util.function.Predicate;

@Getter
@RequiredArgsConstructor
public class Validator<T> {


    private final T t;
    private final List<String> errors = Lists.newArrayList();


    public static <T> Validator<T> unit(T t) {
        return new Validator<>(Objects.requireNonNull(t));
    }

    public <U> Validator<T> mapValidate(Function<T, U> f, Predicate<U> p, String message) {
        return validate(f.andThen(p::test)::apply, message);
    }


    public Validator<T> validate(Predicate<T> p, String message) {
        if (!p.test(t)) {
            errors.add(message);
        }
        return this;
    }

    public <U> Validator<U> flatMap(Function<T, U> f, Function<U, Validator<U>> validator) {
        return f.andThen(validator).apply(t);
    }

}
